@@ -59,6 +59,11 @@ class AzureCloud(IpaCloud):
                 ' are all required to use an existing subnet.'
             )
 
+        if not self.region:
+            raise AzureCloudException(
+                'Region is required to connect to Azure.'
+            )
+
         self.service_account_file = (
             self.custom_args.get('service_account_file')
             or self.ipa_config['service_account_file']
@@ -183,6 +188,10 @@ class AzureCloud(IpaCloud):
                     'sku': self.image_sku,
                     'version': self.image_version
                 },
+                'os_disk': {
+                    'disk_size_gb': self.root_disk_size,
+                    'create_option': 'FromImage'
+                }
             }
         else:
             for image in self.compute.images.list():
@@ -553,9 +562,14 @@ class AzureCloud(IpaCloud):
         Terminate the resource group and instance.
         """
         try:
-            self.resource.resource_groups.delete(
-                self.running_instance_id
-            )
+            if hasattr(self.resource.resource_groups, 'delete'):
+                self.resource.resource_groups.delete(
+                    self.running_instance_id
+                )
+            else:
+                self.resource.resource_groups.begin_delete(
+                    self.running_instance_id
+                )
         except Exception as error:
             raise AzureCloudException(
                 'Unable to terminate resource group: {0}.'.format(error)
