@@ -30,7 +30,6 @@ import pytest
 
 from collections import ChainMap, defaultdict
 from datetime import datetime
-from distutils.util import strtobool
 
 from img_proof import ipa_utils
 from img_proof.ipa_constants import (
@@ -44,6 +43,7 @@ from img_proof.ipa_constants import (
 from img_proof.ipa_rhel import RHEL
 from img_proof.ipa_fedora import Fedora
 from img_proof.ipa_opensuse_leap import openSUSE_Leap
+from img_proof.ipa_sle_micro import SLE_Micro
 from img_proof.ipa_sles import SLES
 from img_proof.ipa_exceptions import (
     IpaException,
@@ -169,7 +169,7 @@ class IpaCloud(object):
         self.enable_secure_boot = self.ipa_config['enable_secure_boot']
         self.enable_uefi = self.ipa_config['enable_uefi']
         self.no_default_test_dirs = bool(
-            strtobool(str(self.ipa_config['no_default_test_dirs']))
+            ipa_utils.strtobool(str(self.ipa_config['no_default_test_dirs']))
         )
         self.prefix_name = self.ipa_config['prefix_name']
         self.retry_count = int(self.ipa_config['retry_count'])
@@ -412,6 +412,8 @@ class IpaCloud(object):
             self.distro = openSUSE_Leap()
         elif self.distro_name == 'rhel':
             self.distro = RHEL()
+        elif self.distro_name == 'sle_micro':
+            self.distro = SLE_Micro()
         elif self.distro_name == 'sles':
             self.distro = SLES()
         else:
